# Shatail


[![PyPI version](https://badge.fury.io/py/shatail.svg)](https://badge.fury.io/py/shatail)
![versions](https://img.shields.io/pypi/pyversions/shatail.svg)
[![GitHub license](https://img.shields.io/github/license/mgancita/shatail.svg)](https://github.com/mgancita/shatail/blob/main/LICENSE)


[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


根据Wagtail修改的Django CMS 系统。


- 开源许可: BSD-3-Clause
- 文档: https://llango.github.io/shatail.


## 特征

* TODO

## 制作


该包使用 [Cookiecutter](https://github.com/audreyr/cookiecutter) 和 [`llango/cookiecutter-mkdoc-shapackage`](https://github.com/llango/cookiecutter-mkdoc-shapackage/) 项目模版创建。
